summaryrefslogtreecommitdiffstats
path: root/sw/source/core/text/txtfly.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/text/txtfly.cxx')
-rw-r--r--sw/source/core/text/txtfly.cxx32
1 files changed, 16 insertions, 16 deletions
diff --git a/sw/source/core/text/txtfly.cxx b/sw/source/core/text/txtfly.cxx
index 76bd7d393555..90d27fd7ea8d 100644
--- a/sw/source/core/text/txtfly.cxx
+++ b/sw/source/core/text/txtfly.cxx
@@ -227,7 +227,7 @@ const SwRect SwContourCache::ContourRect( const SwFormat* pFormat,
tools::PolyPolygon aPoly;
if( !static_cast<const SwVirtFlyDrawObj*>(pObj)->GetFlyFrame()->GetContour( aPoly ) )
aPoly = tools::PolyPolygon( static_cast<const SwVirtFlyDrawObj*>(pObj)->
- GetFlyFrame()->Frame().SVRect() );
+ GetFlyFrame()->getSwFrame().SVRect() );
aPolyPolygon.clear();
aPolyPolygon.append(aPoly.getB2DPolyPolygon());
}
@@ -403,8 +403,8 @@ bool SwTextFly::IsAnyFrame() const
SwSwapIfSwapped swap(const_cast<SwTextFrame *>(pCurrFrame));
OSL_ENSURE( bOn, "IsAnyFrame: Why?" );
- SwRect aRect( pCurrFrame->Frame().Pos() + pCurrFrame->Prt().Pos(),
- pCurrFrame->Prt().SSize() );
+ SwRect aRect( pCurrFrame->getSwFrame().Pos() + pCurrFrame->getSwPrint().Pos(),
+ pCurrFrame->getSwPrint().SSize() );
return ForEach( aRect, nullptr, false );
}
@@ -415,8 +415,8 @@ bool SwTextFly::IsAnyObj( const SwRect &rRect ) const
SwRect aRect( rRect );
if ( aRect.IsEmpty() )
- aRect = SwRect( pCurrFrame->Frame().Pos() + pCurrFrame->Prt().Pos(),
- pCurrFrame->Prt().SSize() );
+ aRect = SwRect( pCurrFrame->getSwFrame().Pos() + pCurrFrame->getSwPrint().Pos(),
+ pCurrFrame->getSwPrint().SSize() );
const SwSortedObjs *pSorted = pPage->GetSortedObjs();
if( pSorted ) // bOn actually makes sure that we have objects on the side,
@@ -501,7 +501,7 @@ bool SwTextFly::DrawTextOpaque( SwDrawTextInfo &rInf )
{
// #i68520#
const SwFlyFrame& rFly = dynamic_cast<const SwFlyFrame&>(*pTmpAnchoredObj);
- if( aRegion.GetOrigin().IsOver( rFly.Frame() ) )
+ if( aRegion.GetOrigin().IsOver( rFly.getSwFrame() ) )
{
const SwFrameFormat *pFormat = rFly.GetFormat();
const SwFormatSurround &rSur = pFormat->GetSurround();
@@ -530,7 +530,7 @@ bool SwTextFly::DrawTextOpaque( SwDrawTextInfo &rInf )
(!pNoText->IsTransparent() && !rSur.IsContour()) )
{
bOpaque = true;
- aRegion -= rFly.Frame();
+ aRegion -= rFly.getSwFrame();
}
}
}
@@ -858,12 +858,12 @@ SwAnchoredObjList* SwTextFly::InitAnchoredObjList()
SwRect aRect;
if ( pIDSA->get(DocumentSettingId::USE_FORMER_TEXT_WRAPPING) )
{
- aRect = pCurrFrame->Prt();
- aRect += pCurrFrame->Frame().Pos();
+ aRect = pCurrFrame->getSwPrint();
+ aRect += pCurrFrame->getSwFrame().Pos();
}
else
{
- aRect = pCurrFrame->Frame();
+ aRect = pCurrFrame->getSwFrame();
}
// Make ourselves a little smaller than we are,
// so that 1-Twip-overlappings are ignored (#49532)
@@ -901,7 +901,7 @@ SwAnchoredObjList* SwTextFly::InitAnchoredObjList()
aRectFnSet.GetBottom(aBound) ) > 0 ||
nLeft > aRectFnSet.GetRight(aBound) ||
aRectFnSet.GetHeight(aBound) >
- 2 * aRectFnSet.GetHeight(pPage->Frame()) )
+ 2 * aRectFnSet.GetHeight(pPage->getSwFrame()) )
{
continue;
}
@@ -969,7 +969,7 @@ SwTwips SwTextFly::CalcMinBottom() const
const size_t nCount = pDrawObj ? pDrawObj->size() : 0;
if( nCount )
{
- SwTwips nEndOfFrame = pCurrFrame->Frame().Bottom();
+ SwTwips nEndOfFrame = pCurrFrame->getSwFrame().Bottom();
for( size_t i = 0; i < nCount; ++i )
{
SwAnchoredObject* pAnchoredObj = (*pDrawObj)[ i ];
@@ -986,8 +986,8 @@ SwTwips SwTextFly::CalcMinBottom() const
}
}
}
- SwTwips nMax = pCurrFrame->GetUpper()->Frame().Top() +
- pCurrFrame->GetUpper()->Prt().Bottom();
+ SwTwips nMax = pCurrFrame->GetUpper()->getSwFrame().Top() +
+ pCurrFrame->GetUpper()->getSwPrint().Bottom();
if( nRet > nMax )
nRet = nMax;
}
@@ -1107,7 +1107,7 @@ void SwTextFly::CalcRightMargin( SwRect &rFly,
// and protrudes into the same line.
// Flys with run-through are invisible for those below, i.e., they
// are ignored for computing the margins of other Flys.
// 3301: pNext->Frame().IsOver( rLine ) is necessary
// #i68520#
css::text::WrapTextMode eSurroundForTextWrap;
@@ -1198,7 +1198,7 @@ void SwTextFly::CalcLeftMargin( SwRect &rFly,
// and protrudes into the same line.
// Flys with run-through are invisible for those below, i.e., they
// are ignored for computing the margins of other Flys.
// 3301: pNext->Frame().IsOver( rLine ) is necessary
// #i68520#
SwAnchoredObjList::size_type nMyPos = nFlyPos;
@@ -1107,7 +1107,7 @@ void SwTextFly::CalcRightMargin( SwRect &rFly,
// Flys with run-through are invisible for those below, i.e., they
// are ignored for computing the margins of other Flys.
- // 3301: pNext->Frame().IsOver( rLine ) is necessary
+ // 3301: pNext->getSwFrame().IsOver( rLine ) is necessary
// #i68520#
css::text::WrapTextMode eSurroundForTextWrap;
@@ -1198,7 +1198,7 @@ void SwTextFly::CalcLeftMargin( SwRect &rFly,
// Flys with run-through are invisible for those below, i.e., they
// are ignored for computing the margins of other Flys.
- // 3301: pNext->Frame().IsOver( rLine ) is necessary
+ // 3301: pNext->getSwFrame().IsOver( rLine ) is necessary
// #i68520#
SwAnchoredObjList::size_type nMyPos = nFlyPos;